# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class RequestProvidersSearch(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        RequestProvidersSearch - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'accepts_insurance': 'bool',
            'hios_ids': 'list[str]',
            'page': 'int',
            'per_page': 'int',
            'radius': 'int',
            'search_term': 'str',
            'zip_code': 'str',
            'type': 'str'
        }

        self.attribute_map = {
            'accepts_insurance': 'accepts_insurance',
            'hios_ids': 'hios_ids',
            'page': 'page',
            'per_page': 'per_page',
            'radius': 'radius',
            'search_term': 'search_term',
            'zip_code': 'zip_code',
            'type': 'type'
        }

        self._accepts_insurance = None
        self._hios_ids = None
        self._page = None
        self._per_page = None
        self._radius = None
        self._search_term = None
        self._zip_code = None
        self._type = None

    @property
    def accepts_insurance(self):
        """
        Gets the accepts_insurance of this RequestProvidersSearch.
        Limit results to Providers who accept at least one insurance
        plan.  Note that the inverse of this filter is not supported and
        any value will evaluate to true

        :return: The accepts_insurance of this RequestProvidersSearch.
        :rtype: bool
        """
        return self._accepts_insurance

    @accepts_insurance.setter
    def accepts_insurance(self, accepts_insurance):
        """
        Sets the accepts_insurance of this RequestProvidersSearch.
        Limit results to Providers who accept at least one insurance
        plan.  Note that the inverse of this filter is not supported and
        any value will evaluate to true

        :param accepts_insurance: The accepts_insurance of this RequestProvidersSearch.
        :type: bool
        """
        self._accepts_insurance = accepts_insurance

    @property
    def hios_ids(self):
        """
        Gets the hios_ids of this RequestProvidersSearch.
        List of HIOS ids

        :return: The hios_ids of this RequestProvidersSearch.
        :rtype: list[str]
        """
        return self._hios_ids

    @hios_ids.setter
    def hios_ids(self, hios_ids):
        """
        Sets the hios_ids of this RequestProvidersSearch.
        List of HIOS ids

        :param hios_ids: The hios_ids of this RequestProvidersSearch.
        :type: list[str]
        """
        self._hios_ids = hios_ids

    @property
    def page(self):
        """
        Gets the page of this RequestProvidersSearch.
        Page number

        :return: The page of this RequestProvidersSearch.
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """
        Sets the page of this RequestProvidersSearch.
        Page number

        :param page: The page of this RequestProvidersSearch.
        :type: int
        """
        self._page = page

    @property
    def per_page(self):
        """
        Gets the per_page of this RequestProvidersSearch.
        Number of records to return per page

        :return: The per_page of this RequestProvidersSearch.
        :rtype: int
        """
        return self._per_page

    @per_page.setter
    def per_page(self, per_page):
        """
        Sets the per_page of this RequestProvidersSearch.
        Number of records to return per page

        :param per_page: The per_page of this RequestProvidersSearch.
        :type: int
        """
        self._per_page = per_page

    @property
    def radius(self):
        """
        Gets the radius of this RequestProvidersSearch.
        Radius (in miles) to use to limit results

        :return: The radius of this RequestProvidersSearch.
        :rtype: int
        """
        return self._radius

    @radius.setter
    def radius(self, radius):
        """
        Sets the radius of this RequestProvidersSearch.
        Radius (in miles) to use to limit results

        :param radius: The radius of this RequestProvidersSearch.
        :type: int
        """
        self._radius = radius

    @property
    def search_term(self):
        """
        Gets the search_term of this RequestProvidersSearch.
        String to search by

        :return: The search_term of this RequestProvidersSearch.
        :rtype: str
        """
        return self._search_term

    @search_term.setter
    def search_term(self, search_term):
        """
        Sets the search_term of this RequestProvidersSearch.
        String to search by

        :param search_term: The search_term of this RequestProvidersSearch.
        :type: str
        """
        self._search_term = search_term

    @property
    def zip_code(self):
        """
        Gets the zip_code of this RequestProvidersSearch.
        Zip Code to search near

        :return: The zip_code of this RequestProvidersSearch.
        :rtype: str
        """
        return self._zip_code

    @zip_code.setter
    def zip_code(self, zip_code):
        """
        Sets the zip_code of this RequestProvidersSearch.
        Zip Code to search near

        :param zip_code: The zip_code of this RequestProvidersSearch.
        :type: str
        """
        self._zip_code = zip_code

    @property
    def type(self):
        """
        Gets the type of this RequestProvidersSearch.
        Either organization or individual

        :return: The type of this RequestProvidersSearch.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this RequestProvidersSearch.
        Either organization or individual

        :param type: The type of this RequestProvidersSearch.
        :type: str
        """
        self._type = type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Pricing(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Pricing - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'age': 'int',
            'effective_date': 'date',
            'expiration_date': 'date',
            'plan_id': 'int',
            'premium_child_only': 'float',
            'premium_family': 'float',
            'premium_single': 'float',
            'premium_single_and_children': 'float',
            'premium_single_and_spouse': 'float',
            'premium_single_smoker': 'float',
            'rating_area_id': 'str'
        }

        self.attribute_map = {
            'age': 'age',
            'effective_date': 'effective_date',
            'expiration_date': 'expiration_date',
            'plan_id': 'plan_id',
            'premium_child_only': 'premium_child_only',
            'premium_family': 'premium_family',
            'premium_single': 'premium_single',
            'premium_single_and_children': 'premium_single_and_children',
            'premium_single_and_spouse': 'premium_single_and_spouse',
            'premium_single_smoker': 'premium_single_smoker',
            'rating_area_id': 'rating_area_id'
        }

        self._age = None
        self._effective_date = None
        self._expiration_date = None
        self._plan_id = None
        self._premium_child_only = None
        self._premium_family = None
        self._premium_single = None
        self._premium_single_and_children = None
        self._premium_single_and_spouse = None
        self._premium_single_smoker = None
        self._rating_area_id = None

    @property
    def age(self):
        """
        Gets the age of this Pricing.
        Age of applicant

        :return: The age of this Pricing.
        :rtype: int
        """
        return self._age

    @age.setter
    def age(self, age):
        """
        Sets the age of this Pricing.
        Age of applicant

        :param age: The age of this Pricing.
        :type: int
        """
        self._age = age

    @property
    def effective_date(self):
        """
        Gets the effective_date of this Pricing.
        Effective date of plan

        :return: The effective_date of this Pricing.
        :rtype: date
        """
        return self._effective_date

    @effective_date.setter
    def effective_date(self, effective_date):
        """
        Sets the effective_date of this Pricing.
        Effective date of plan

        :param effective_date: The effective_date of this Pricing.
        :type: date
        """
        self._effective_date = effective_date

    @property
    def expiration_date(self):
        """
        Gets the expiration_date of this Pricing.
        Plan expiration date

        :return: The expiration_date of this Pricing.
        :rtype: date
        """
        return self._expiration_date

    @expiration_date.setter
    def expiration_date(self, expiration_date):
        """
        Sets the expiration_date of this Pricing.
        Plan expiration date

        :param expiration_date: The expiration_date of this Pricing.
        :type: date
        """
        self._expiration_date = expiration_date

    @property
    def plan_id(self):
        """
        Gets the plan_id of this Pricing.
        Foreign key to plans

        :return: The plan_id of this Pricing.
        :rtype: int
        """
        return self._plan_id

    @plan_id.setter
    def plan_id(self, plan_id):
        """
        Sets the plan_id of this Pricing.
        Foreign key to plans

        :param plan_id: The plan_id of this Pricing.
        :type: int
        """
        self._plan_id = plan_id

    @property
    def premium_child_only(self):
        """
        Gets the premium_child_only of this Pricing.
        Child-only premium

        :return: The premium_child_only of this Pricing.
        :rtype: float
        """
        return self._premium_child_only

    @premium_child_only.setter
    def premium_child_only(self, premium_child_only):
        """
        Sets the premium_child_only of this Pricing.
        Child-only premium

        :param premium_child_only: The premium_child_only of this Pricing.
        :type: float
        """
        self._premium_child_only = premium_child_only

    @property
    def premium_family(self):
        """
        Gets the premium_family of this Pricing.
        Family premium

        :return: The premium_family of this Pricing.
        :rtype: float
        """
        return self._premium_family

    @premium_family.setter
    def premium_family(self, premium_family):
        """
        Sets the premium_family of this Pricing.
        Family premium

        :param premium_family: The premium_family of this Pricing.
        :type: float
        """
        self._premium_family = premium_family

    @property
    def premium_single(self):
        """
        Gets the premium_single of this Pricing.
        Single-person premium

        :return: The premium_single of this Pricing.
        :rtype: float
        """
        return self._premium_single

    @premium_single.setter
    def premium_single(self, premium_single):
        """
        Sets the premium_single of this Pricing.
        Single-person premium

        :param premium_single: The premium_single of this Pricing.
        :type: float
        """
        self._premium_single = premium_single

    @property
    def premium_single_and_children(self):
        """
        Gets the premium_single_and_children of this Pricing.
        Single person including children premium

        :return: The premium_single_and_children of this Pricing.
        :rtype: float
        """
        return self._premium_single_and_children

    @premium_single_and_children.setter
    def premium_single_and_children(self, premium_single_and_children):
        """
        Sets the premium_single_and_children of this Pricing.
        Single person including children premium

        :param premium_single_and_children: The premium_single_and_children of this Pricing.
        :type: float
        """
        self._premium_single_and_children = premium_single_and_children

    @property
    def premium_single_and_spouse(self):
        """
        Gets the premium_single_and_spouse of this Pricing.
        Person with spouse premium

        :return: The premium_single_and_spouse of this Pricing.
        :rtype: float
        """
        return self._premium_single_and_spouse

    @premium_single_and_spouse.setter
    def premium_single_and_spouse(self, premium_single_and_spouse):
        """
        Sets the premium_single_and_spouse of this Pricing.
        Person with spouse premium

        :param premium_single_and_spouse: The premium_single_and_spouse of this Pricing.
        :type: float
        """
        self._premium_single_and_spouse = premium_single_and_spouse

    @property
    def premium_single_smoker(self):
        """
        Gets the premium_single_smoker of this Pricing.
        Premium for single smoker

        :return: The premium_single_smoker of this Pricing.
        :rtype: float
        """
        return self._premium_single_smoker

    @premium_single_smoker.setter
    def premium_single_smoker(self, premium_single_smoker):
        """
        Sets the premium_single_smoker of this Pricing.
        Premium for single smoker

        :param premium_single_smoker: The premium_single_smoker of this Pricing.
        :type: float
        """
        self._premium_single_smoker = premium_single_smoker

    @property
    def rating_area_id(self):
        """
        Gets the rating_area_id of this Pricing.
        Foreign key to rating areas

        :return: The rating_area_id of this Pricing.
        :rtype: str
        """
        return self._rating_area_id

    @rating_area_id.setter
    def rating_area_id(self, rating_area_id):
        """
        Sets the rating_area_id of this Pricing.
        Foreign key to rating areas

        :param rating_area_id: The rating_area_id of this Pricing.
        :type: str
        """
        self._rating_area_id = rating_area_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




from __future__ import absolute_import

# import apis into api package
from .drugs_api import DrugsApi
from .networks_api import NetworksApi
from .plans_api import PlansApi
from .providers_api import ProvidersApi
from .zip_counties_api import ZipCountiesApi



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Applicant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Applicant - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'int',
            'dob': 'date',
            'member_id': 'str',
            'name': 'str',
            'relationship': 'str',
            'smoker': 'bool',
            'ssn': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'dob': 'dob',
            'member_id': 'member_id',
            'name': 'name',
            'relationship': 'relationship',
            'smoker': 'smoker',
            'ssn': 'ssn'
        }

        self._id = None
        self._dob = None
        self._member_id = None
        self._name = None
        self._relationship = None
        self._smoker = None
        self._ssn = None

    @property
    def id(self):
        """
        Gets the id of this Applicant.
        Primary key

        :return: The id of this Applicant.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Applicant.
        Primary key

        :param id: The id of this Applicant.
        :type: int
        """
        self._id = id

    @property
    def dob(self):
        """
        Gets the dob of this Applicant.
        Date of Birth

        :return: The dob of this Applicant.
        :rtype: date
        """
        return self._dob

    @dob.setter
    def dob(self, dob):
        """
        Sets the dob of this Applicant.
        Date of Birth

        :param dob: The dob of this Applicant.
        :type: date
        """
        self._dob = dob

    @property
    def member_id(self):
        """
        Gets the member_id of this Applicant.
        Member token

        :return: The member_id of this Applicant.
        :rtype: str
        """
        return self._member_id

    @member_id.setter
    def member_id(self, member_id):
        """
        Sets the member_id of this Applicant.
        Member token

        :param member_id: The member_id of this Applicant.
        :type: str
        """
        self._member_id = member_id

    @property
    def name(self):
        """
        Gets the name of this Applicant.
        Full name of the Applicant

        :return: The name of this Applicant.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Applicant.
        Full name of the Applicant

        :param name: The name of this Applicant.
        :type: str
        """
        self._name = name

    @property
    def relationship(self):
        """
        Gets the relationship of this Applicant.
        Relationship of the Applicant to the Member

        :return: The relationship of this Applicant.
        :rtype: str
        """
        return self._relationship

    @relationship.setter
    def relationship(self, relationship):
        """
        Sets the relationship of this Applicant.
        Relationship of the Applicant to the Member

        :param relationship: The relationship of this Applicant.
        :type: str
        """
        self._relationship = relationship

    @property
    def smoker(self):
        """
        Gets the smoker of this Applicant.
        Does the Applicant smoke?

        :return: The smoker of this Applicant.
        :rtype: bool
        """
        return self._smoker

    @smoker.setter
    def smoker(self, smoker):
        """
        Sets the smoker of this Applicant.
        Does the Applicant smoke?

        :param smoker: The smoker of this Applicant.
        :type: bool
        """
        self._smoker = smoker

    @property
    def ssn(self):
        """
        Gets the ssn of this Applicant.
        Applicant's Social Security Number

        :return: The ssn of this Applicant.
        :rtype: str
        """
        return self._ssn

    @ssn.setter
    def ssn(self, ssn):
        """
        Sets the ssn of this Applicant.
        Applicant's Social Security Number

        :param ssn: The ssn of this Applicant.
        :type: str
        """
        self._ssn = ssn

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
PlansApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class PlansApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def find_plans(self, **kwargs):
        """
        Find Plans
        ### Location Information

Searching for a set of plans requires a `zip_code` and `fips_code`
code.  These are used to determine pricing and availabity
of health plans.

Optionally, you may provide a list of Applicants or Providers

### Applicants

This is a list of people who will be covered by the plan.  We
use this list to calculate the premium.  You must include `age`
and can include `smoker`, which also factors into pricing in some
states.

Applicants *must* include an age.  If smoker is omitted, its value is assumed
to be false.

#### Multiple Applicants
To get pricing for multiple applicants, just append multiple sets
of data to the URL with the age and smoking status of each applicant
next to each other.

For example, given two applicants - one age 32 and a non-smoker and one
age 29 and a smoker, you could use the following request

`GET /plans?zip_code=07451&fips_code=33025&applicants[][age]=32&applicants[][age]=29&applicants[][smoker]=true`

It would also be acceptible to include `applicants[][smoker]=false` after the
first applicant's age.

### Providers

We identify Providers (Doctors) by their National Practitioner
Index number (NPI).  If you pass a list of Providers, keyed by
their NPI number, we will return a list of which Providers are
in and out of network for each plan returned.

For example, if we had two providers with the NPI numbers `12345` and `23456`
you would make the following request

`GET /plans?zip_code=07451&fips_code=33025&providers[][npi]=12345&providers[][npi]=23456`

### Enrollment Date

To calculate plan pricing and availability, we default to the current date
as the enrollment date.  To specify a date in the future (or the past), pass
a string with the format `YYYY-MM-DD` in the `enrollment_date` parameter.

`GET /plans?zip_code=07451&fips_code=33025&enrollment_date=2016-01-01`

### Subsidy

On-marketplace plans are eligible for a subsidy based on the
`household_size` and `household_income` of the applicants.  If you
pass those values, we will calculate the `subsidized_premium`
and return it for each plan.  If no values are provided, the
`subsidized_premium` will be the same as the `premium`

`GET /plans?zip_code=07451&fips_code=33025&household_size=4&household_income=40000`


        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.find_plans(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param RequestPlanFind body: 
        :return: PlanSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_plans" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/plans/search'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept([])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = []

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='PlanSearchResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class ZipCountyResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ZipCountyResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'counties': 'list[County]',
            'states': 'list[State]',
            'zip_codes': 'list[ZipCode]',
            'zip_county': 'ZipCounty'
        }

        self.attribute_map = {
            'counties': 'counties',
            'states': 'states',
            'zip_codes': 'zip_codes',
            'zip_county': 'zip_county'
        }

        self._counties = None
        self._states = None
        self._zip_codes = None
        self._zip_county = None

    @property
    def counties(self):
        """
        Gets the counties of this ZipCountyResponse.
        Counties that exist in the provided zip prefix.

        :return: The counties of this ZipCountyResponse.
        :rtype: list[County]
        """
        return self._counties

    @counties.setter
    def counties(self, counties):
        """
        Sets the counties of this ZipCountyResponse.
        Counties that exist in the provided zip prefix.

        :param counties: The counties of this ZipCountyResponse.
        :type: list[County]
        """
        self._counties = counties

    @property
    def states(self):
        """
        Gets the states of this ZipCountyResponse.
        States that exist in the provided zip prefix.

        :return: The states of this ZipCountyResponse.
        :rtype: list[State]
        """
        return self._states

    @states.setter
    def states(self, states):
        """
        Sets the states of this ZipCountyResponse.
        States that exist in the provided zip prefix.

        :param states: The states of this ZipCountyResponse.
        :type: list[State]
        """
        self._states = states

    @property
    def zip_codes(self):
        """
        Gets the zip_codes of this ZipCountyResponse.
        ZipCodes that exist in the provided zip prefix.

        :return: The zip_codes of this ZipCountyResponse.
        :rtype: list[ZipCode]
        """
        return self._zip_codes

    @zip_codes.setter
    def zip_codes(self, zip_codes):
        """
        Sets the zip_codes of this ZipCountyResponse.
        ZipCodes that exist in the provided zip prefix.

        :param zip_codes: The zip_codes of this ZipCountyResponse.
        :type: list[ZipCode]
        """
        self._zip_codes = zip_codes

    @property
    def zip_county(self):
        """
        Gets the zip_county of this ZipCountyResponse.
        ZipCounty data

        :return: The zip_county of this ZipCountyResponse.
        :rtype: ZipCounty
        """
        return self._zip_county

    @zip_county.setter
    def zip_county(self, zip_county):
        """
        Sets the zip_county of this ZipCountyResponse.
        ZipCounty data

        :param zip_county: The zip_county of this ZipCountyResponse.
        :type: ZipCounty
        """
        self._zip_county = zip_county

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class RequestPlanFind(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        RequestPlanFind - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'applicants': 'list[RequestPlanFindApplicant]',
            'enrollment_date': 'str',
            'drug_packages': 'list[DrugPackage]',
            'fips_code': 'str',
            'household_income': 'int',
            'household_size': 'int',
            'market': 'str',
            'providers': 'list[RequestPlanFindProvider]',
            'zip_code': 'str'
        }

        self.attribute_map = {
            'applicants': 'applicants',
            'enrollment_date': 'enrollment_date',
            'drug_packages': 'drug_packages',
            'fips_code': 'fips_code',
            'household_income': 'household_income',
            'household_size': 'household_size',
            'market': 'market',
            'providers': 'providers',
            'zip_code': 'zip_code'
        }

        self._applicants = None
        self._enrollment_date = None
        self._drug_packages = None
        self._fips_code = None
        self._household_income = None
        self._household_size = None
        self._market = None
        self._providers = None
        self._zip_code = None

    @property
    def applicants(self):
        """
        Gets the applicants of this RequestPlanFind.
        Applicants for desired plans.

        :return: The applicants of this RequestPlanFind.
        :rtype: list[RequestPlanFindApplicant]
        """
        return self._applicants

    @applicants.setter
    def applicants(self, applicants):
        """
        Sets the applicants of this RequestPlanFind.
        Applicants for desired plans.

        :param applicants: The applicants of this RequestPlanFind.
        :type: list[RequestPlanFindApplicant]
        """
        self._applicants = applicants

    @property
    def enrollment_date(self):
        """
        Gets the enrollment_date of this RequestPlanFind.
        Date of enrollment

        :return: The enrollment_date of this RequestPlanFind.
        :rtype: str
        """
        return self._enrollment_date

    @enrollment_date.setter
    def enrollment_date(self, enrollment_date):
        """
        Sets the enrollment_date of this RequestPlanFind.
        Date of enrollment

        :param enrollment_date: The enrollment_date of this RequestPlanFind.
        :type: str
        """
        self._enrollment_date = enrollment_date

    @property
    def drug_packages(self):
        """
        Gets the drug_packages of this RequestPlanFind.
        National Drug Code Package Id

        :return: The drug_packages of this RequestPlanFind.
        :rtype: list[DrugPackage]
        """
        return self._drug_packages

    @drug_packages.setter
    def drug_packages(self, drug_packages):
        """
        Sets the drug_packages of this RequestPlanFind.
        National Drug Code Package Id

        :param drug_packages: The drug_packages of this RequestPlanFind.
        :type: list[DrugPackage]
        """
        self._drug_packages = drug_packages

    @property
    def fips_code(self):
        """
        Gets the fips_code of this RequestPlanFind.
        County code to determine eligibility

        :return: The fips_code of this RequestPlanFind.
        :rtype: str
        """
        return self._fips_code

    @fips_code.setter
    def fips_code(self, fips_code):
        """
        Sets the fips_code of this RequestPlanFind.
        County code to determine eligibility

        :param fips_code: The fips_code of this RequestPlanFind.
        :type: str
        """
        self._fips_code = fips_code

    @property
    def household_income(self):
        """
        Gets the household_income of this RequestPlanFind.
        Total household income.

        :return: The household_income of this RequestPlanFind.
        :rtype: int
        """
        return self._household_income

    @household_income.setter
    def household_income(self, household_income):
        """
        Sets the household_income of this RequestPlanFind.
        Total household income.

        :param household_income: The household_income of this RequestPlanFind.
        :type: int
        """
        self._household_income = household_income

    @property
    def household_size(self):
        """
        Gets the household_size of this RequestPlanFind.
        Number of people living in household.

        :return: The household_size of this RequestPlanFind.
        :rtype: int
        """
        return self._household_size

    @household_size.setter
    def household_size(self, household_size):
        """
        Sets the household_size of this RequestPlanFind.
        Number of people living in household.

        :param household_size: The household_size of this RequestPlanFind.
        :type: int
        """
        self._household_size = household_size

    @property
    def market(self):
        """
        Gets the market of this RequestPlanFind.
        Type of plan to search for.

        :return: The market of this RequestPlanFind.
        :rtype: str
        """
        return self._market

    @market.setter
    def market(self, market):
        """
        Sets the market of this RequestPlanFind.
        Type of plan to search for.

        :param market: The market of this RequestPlanFind.
        :type: str
        """
        self._market = market

    @property
    def providers(self):
        """
        Gets the providers of this RequestPlanFind.
        List of providers to search for.

        :return: The providers of this RequestPlanFind.
        :rtype: list[RequestPlanFindProvider]
        """
        return self._providers

    @providers.setter
    def providers(self, providers):
        """
        Sets the providers of this RequestPlanFind.
        List of providers to search for.

        :param providers: The providers of this RequestPlanFind.
        :type: list[RequestPlanFindProvider]
        """
        self._providers = providers

    @property
    def zip_code(self):
        """
        Gets the zip_code of this RequestPlanFind.
        5-digit zip code - this helps determine pricing.

        :return: The zip_code of this RequestPlanFind.
        :rtype: str
        """
        return self._zip_code

    @zip_code.setter
    def zip_code(self, zip_code):
        """
        Sets the zip_code of this RequestPlanFind.
        5-digit zip code - this helps determine pricing.

        :param zip_code: The zip_code of this RequestPlanFind.
        :type: str
        """
        self._zip_code = zip_code

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class State(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        State - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'int',
            'name': 'str',
            'code': 'str',
            'fips_number': 'str',
            'last_date_for_individual': 'date',
            'last_date_for_shop': 'date',
            'live_for_business': 'bool',
            'live_for_consumers': 'bool'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'code': 'code',
            'fips_number': 'fips_number',
            'last_date_for_individual': 'last_date_for_individual',
            'last_date_for_shop': 'last_date_for_shop',
            'live_for_business': 'live_for_business',
            'live_for_consumers': 'live_for_consumers'
        }

        self._id = None
        self._name = None
        self._code = None
        self._fips_number = None
        self._last_date_for_individual = None
        self._last_date_for_shop = None
        self._live_for_business = None
        self._live_for_consumers = None

    @property
    def id(self):
        """
        Gets the id of this State.
        Primary Key of State

        :return: The id of this State.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this State.
        Primary Key of State

        :param id: The id of this State.
        :type: int
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this State.
        Name of state

        :return: The name of this State.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this State.
        Name of state

        :param name: The name of this State.
        :type: str
        """
        self._name = name

    @property
    def code(self):
        """
        Gets the code of this State.
        2 letter code for state

        :return: The code of this State.
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """
        Sets the code of this State.
        2 letter code for state

        :param code: The code of this State.
        :type: str
        """
        self._code = code

    @property
    def fips_number(self):
        """
        Gets the fips_number of this State.
        National FIPs number

        :return: The fips_number of this State.
        :rtype: str
        """
        return self._fips_number

    @fips_number.setter
    def fips_number(self, fips_number):
        """
        Sets the fips_number of this State.
        National FIPs number

        :param fips_number: The fips_number of this State.
        :type: str
        """
        self._fips_number = fips_number

    @property
    def last_date_for_individual(self):
        """
        Gets the last_date_for_individual of this State.
        Last date this state is live for individuals

        :return: The last_date_for_individual of this State.
        :rtype: date
        """
        return self._last_date_for_individual

    @last_date_for_individual.setter
    def last_date_for_individual(self, last_date_for_individual):
        """
        Sets the last_date_for_individual of this State.
        Last date this state is live for individuals

        :param last_date_for_individual: The last_date_for_individual of this State.
        :type: date
        """
        self._last_date_for_individual = last_date_for_individual

    @property
    def last_date_for_shop(self):
        """
        Gets the last_date_for_shop of this State.
        Last date this state is live for shop

        :return: The last_date_for_shop of this State.
        :rtype: date
        """
        return self._last_date_for_shop

    @last_date_for_shop.setter
    def last_date_for_shop(self, last_date_for_shop):
        """
        Sets the last_date_for_shop of this State.
        Last date this state is live for shop

        :param last_date_for_shop: The last_date_for_shop of this State.
        :type: date
        """
        self._last_date_for_shop = last_date_for_shop

    @property
    def live_for_business(self):
        """
        Gets the live_for_business of this State.
        Is this State available for businesses

        :return: The live_for_business of this State.
        :rtype: bool
        """
        return self._live_for_business

    @live_for_business.setter
    def live_for_business(self, live_for_business):
        """
        Sets the live_for_business of this State.
        Is this State available for businesses

        :param live_for_business: The live_for_business of this State.
        :type: bool
        """
        self._live_for_business = live_for_business

    @property
    def live_for_consumers(self):
        """
        Gets the live_for_consumers of this State.
        Is this State available for individuals

        :return: The live_for_consumers of this State.
        :rtype: bool
        """
        return self._live_for_consumers

    @live_for_consumers.setter
    def live_for_consumers(self, live_for_consumers):
        """
        Sets the live_for_consumers of this State.
        Is this State available for individuals

        :param live_for_consumers: The live_for_consumers of this State.
        :type: bool
        """
        self._live_for_consumers = live_for_consumers

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class County(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        County - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'int',
            'fips_code': 'str',
            'name': 'str',
            'state_code': 'str',
            'state_id': 'int',
            'state_live': 'bool',
            'state_live_for_business': 'bool'
        }

        self.attribute_map = {
            'id': 'id',
            'fips_code': 'fips_code',
            'name': 'name',
            'state_code': 'state_code',
            'state_id': 'state_id',
            'state_live': 'state_live',
            'state_live_for_business': 'state_live_for_business'
        }

        self._id = None
        self._fips_code = None
        self._name = None
        self._state_code = None
        self._state_id = None
        self._state_live = None
        self._state_live_for_business = None

    @property
    def id(self):
        """
        Gets the id of this County.
        Primary key

        :return: The id of this County.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this County.
        Primary key

        :param id: The id of this County.
        :type: int
        """
        self._id = id

    @property
    def fips_code(self):
        """
        Gets the fips_code of this County.
        State FIPS code

        :return: The fips_code of this County.
        :rtype: str
        """
        return self._fips_code

    @fips_code.setter
    def fips_code(self, fips_code):
        """
        Sets the fips_code of this County.
        State FIPS code

        :param fips_code: The fips_code of this County.
        :type: str
        """
        self._fips_code = fips_code

    @property
    def name(self):
        """
        Gets the name of this County.
        Human-readable name

        :return: The name of this County.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this County.
        Human-readable name

        :param name: The name of this County.
        :type: str
        """
        self._name = name

    @property
    def state_code(self):
        """
        Gets the state_code of this County.
        Two-character state code

        :return: The state_code of this County.
        :rtype: str
        """
        return self._state_code

    @state_code.setter
    def state_code(self, state_code):
        """
        Sets the state_code of this County.
        Two-character state code

        :param state_code: The state_code of this County.
        :type: str
        """
        self._state_code = state_code

    @property
    def state_id(self):
        """
        Gets the state_id of this County.
        state relationship

        :return: The state_id of this County.
        :rtype: int
        """
        return self._state_id

    @state_id.setter
    def state_id(self, state_id):
        """
        Sets the state_id of this County.
        state relationship

        :param state_id: The state_id of this County.
        :type: int
        """
        self._state_id = state_id

    @property
    def state_live(self):
        """
        Gets the state_live of this County.
        Is the state containing this county active for consumers?(deprecated in favor of last_date_for_individual)

        :return: The state_live of this County.
        :rtype: bool
        """
        return self._state_live

    @state_live.setter
    def state_live(self, state_live):
        """
        Sets the state_live of this County.
        Is the state containing this county active for consumers?(deprecated in favor of last_date_for_individual)

        :param state_live: The state_live of this County.
        :type: bool
        """
        self._state_live = state_live

    @property
    def state_live_for_business(self):
        """
        Gets the state_live_for_business of this County.
        Is the state containing this county active for business?(deprecated in favor of last_date_for_shop)

        :return: The state_live_for_business of this County.
        :rtype: bool
        """
        return self._state_live_for_business

    @state_live_for_business.setter
    def state_live_for_business(self, state_live_for_business):
        """
        Sets the state_live_for_business of this County.
        Is the state containing this county active for business?(deprecated in favor of last_date_for_shop)

        :param state_live_for_business: The state_live_for_business of this County.
        :type: bool
        """
        self._state_live_for_business = state_live_for_business

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

